@@ -67,9 +67,9 @@ pub fn vtable(attr: TokenStreamRaw, item: TokenStreamRaw) -> TokenStreamRaw {
 	let vtable_members = methods.iter().map(|(r, sig)| {
 		let name = &sig.ident;
 		let this = if r.mutability.is_some() {
-			quote! {core::pin::Pin<&mut cppvtbl::VtableRef<Self>>}
+			quote! {core::pin::Pin<&mut ::cppvtbl::VtableRef<Self>>}
 		} else {
-			quote! {&cppvtbl::VtableRef<Self>}
+			quote! {&::cppvtbl::VtableRef<Self>}
 		};
 		let inputs = sig.inputs.iter().skip(1);
 		let output = &sig.output;
@@ -80,17 +80,17 @@ pub fn vtable(attr: TokenStreamRaw, item: TokenStreamRaw) -> TokenStreamRaw {
 	let macro_vtable_fields = methods.iter().map(|(r, sig)| {
 		let meth = &sig.ident;
 		let this = if r.mutability.is_some() {
-			quote! {core::pin::Pin<&mut cppvtbl::VtableRef<#vtable_name>>}
+			quote! {core::pin::Pin<&mut ::cppvtbl::VtableRef<#vtable_name>>}
 		} else {
-			quote! {&cppvtbl::VtableRef<#vtable_name>}
+			quote! {&::cppvtbl::VtableRef<#vtable_name>}
 		};
 		let get_top = if r.mutability.is_some() {
 			quote! {
-				 let top: &mut cppvtbl::WithVtables<$this> = core::mem::transmute((core::pin::Pin::get_unchecked_mut(this) as *mut _ as *mut usize).offset($offset))
+				 let top: &mut ::cppvtbl::WithVtables<$this> = core::mem::transmute((core::pin::Pin::get_unchecked_mut(this) as *mut _ as *mut usize).offset($offset))
 			}
 		} else {
 			quote! {
-				let top: &cppvtbl::WithVtables<$this> = core::mem::transmute((this as *const _ as *const usize).offset($offset))
+				let top: &::cppvtbl::WithVtables<$this> = core::mem::transmute((this as *const _ as *const usize).offset($offset))
 			}
 		};
 		let inputs = sig.inputs.iter().skip(1);
@@ -198,10 +198,10 @@ pub fn vtable(attr: TokenStreamRaw, item: TokenStreamRaw) -> TokenStreamRaw {
 				};
 			}
 		}
-		impl #name for cppvtbl::VtableRef<#vtable_name> {
+		impl #name for ::cppvtbl::VtableRef<#vtable_name> {
 			#(#impl_members)*
 		}
-		impl #name for core::pin::Pin<&mut cppvtbl::VtableRef<#vtable_name>> {
+		impl #name for core::pin::Pin<&mut ::cppvtbl::VtableRef<#vtable_name>> {
 			#(#impl_mut_members)*
 		}
 
@@ -238,24 +238,24 @@ pub fn impl_vtables(attr: TokenStreamRaw, item: TokenStreamRaw) -> TokenStreamRa
 	let type_tables = input.tables.iter().map(|name| {
 		let vtable_name = format_ident!("{}Vtable", name);
 		quote! {
-			cppvtbl::VtableRef<#vtable_name>
+			::cppvtbl::VtableRef<#vtable_name>
 		}
 	});
 	let impl_tables = input.tables.iter().map(|name| {
 		let const_name = format_ident!("{}VtableFor{}", name, this_name);
 		quote! {
-			unsafe { cppvtbl::VtableRef::new(#const_name) }
+			unsafe { ::cppvtbl::VtableRef::new(#const_name) }
 		}
 	});
 	let has_vtable = input.tables.iter().enumerate().map(|(i, name)| {
 		let vtable_name = format_ident!("{}Vtable", name);
 		let index = Index::from(i);
 		quote! {
-			impl cppvtbl::HasVtable<#vtable_name> for #this_name {
-				fn get(from: &cppvtbl::WithVtables<Self>) -> &cppvtbl::VtableRef<#vtable_name> {
+			impl ::cppvtbl::HasVtable<#vtable_name> for #this_name {
+				fn get(from: &::cppvtbl::WithVtables<Self>) -> &::cppvtbl::VtableRef<#vtable_name> {
 					&from.vtables().#index
 				}
-				fn get_mut(from: &mut cppvtbl::WithVtables<Self>) -> core::pin::Pin<&mut cppvtbl::VtableRef<#vtable_name>> {
+				fn get_mut(from: &mut ::cppvtbl::WithVtables<Self>) -> core::pin::Pin<&mut ::cppvtbl::VtableRef<#vtable_name>> {
 					unsafe { core::pin::Pin::new_unchecked(&mut (&mut *from.vtables_mut()).#index) }
 				}
 			}
@@ -265,7 +265,7 @@ pub fn impl_vtables(attr: TokenStreamRaw, item: TokenStreamRaw) -> TokenStreamRa
 	(quote! {
 		#this
 		#(#impl_macro_calls;)*
-		unsafe impl cppvtbl::HasVtables for #this_name {
+		unsafe impl ::cppvtbl::HasVtables for #this_name {
 			type Tables = (#(#type_tables,)*);
 			const TABLES: Self::Tables = (#(#impl_tables,)*);
 		}
